#!/bin/bash
#

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}:${PRODUCTS}
    if [ -z ${SSIBUILDSHIMS_DIR} ]
    then
       echo "ERROR: failed to setup ssibuildshims ${ssibuildshims_version}"
       exit 1
    fi
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
maketar=${2}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=eigen
origpkgver=v3_3_4
pkgver=${origpkgver}a
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
ssibuildshims_version=v1_04_04
eigentar=eigen-eigen-5a0156e40feb

get_this_dir

get_ssibuildshims

source define_basics NO_QUAL NO_FQ_DIR

##pkgdir=${product_dir}/${package}/${pkgver}
##blddir=${product_dir}/${package}/${pkgver}/build/NULL
##tardir=${product_dir}/${package}/${pkgver}/tar
srcdir=${product_dir}/${package}/${pkgver}/build/src

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/include ]
then
    ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_FLAVOR
    exit 0
fi

echo "building ${package}"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${pkgdir}
if [ ! -d ${pkgdir} ]
then
   echo "ERROR: failed to create ${pkgdir}"
   exit 1
fi
mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi
mkdir -p ${srcdir}
if [ ! -d ${srcdir} ]
then
   echo "ERROR: failed to create ${srcdir}"
   exit 1
fi

source setup_cmake

set -x

cd ${srcdir}
tar xf ${tardir}/${eigentar}.tar.bz2 || ssi_die "Unable to unwind ${tardir}/${eigentar}.tar.bz2"

cd ${srcdir}/${eigentar} || ssi_die "Unable to access ${srcdir}/${eigentar}"
patch -b -p1 < ${patchdir}/cxx17.patch || ssi_die "patch failed"

cd ${blddir}
cmake  -DCMAKE_INSTALL_PREFIX=${pkgdir} ${srcdir}/${eigentar}
make install  || ssi_die "'make install' failed"

set +x

if [ ! -d ${pkgdir}/include ]
then
   echo "ERROR: failed to create ${pkgdir}/include"
   echo "       Something is very wrong"
   exit 1
fi


# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} NO_FLAVOR || \
  ssi_die "Unable to declare product to UPS."

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -z ${product_dir}:${PRODUCTS} || ssi_die "ERROR: setup failed"

# fix the pkgconfig file
mv ${EIGEN_DIR}/share/pkgconfig/eigen3.pc ${EIGEN_DIR}/share/pkgconfig/eigen3.pc.bak
cat ${EIGEN_DIR}/share/pkgconfig/eigen3.pc.bak | sed "s%${EIGEN_DIR}%\${pcfiledir}/../..%g" > ${EIGEN_DIR}/share/pkgconfig/eigen3.pc


# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/include ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_FLAVOR
fi

exit 0
